local myname, mm = ...
local _G = getfenv(0)

local err = mm.err
local L = mm.L
local version = _G.GetAddOnMetadata(myname, "Version")


local myOptionsTable = {
	name = ("%s - %s"):format(myname,version),
	type = "group",
	order = 1,
	icon = "Interface\\Icons\\INV_Misc_Book_01",
	args = {
		header1 = {
			type = 'header',
			name = "",
			width = "full",
			order = 0.1,
		},
		enable = {
			name = (L["Enable %s"]):format(myname),
			desc = L["Enables / disables the addon"],
			type = "toggle",
			width = "full",
			set = function(info,val) 
				mm.sessionDB.enabled = val 
				if val then
					mm:Enable()
				else
					mm:Disable()
				end
			end,
			get = function(info) return mm.sessionDB.enabled end,
			order = 0.2,
		},
		weight = {
			name = L["Random Weight"],
			desc = L["Weight for the non-favorite mounts from 0% to 100%. Use 0 if you only want the favorite mounts to be selected."],
			type = "range",
			width = "full",
			min = 0,
			max = 1,
			step = .05,
			isPercent = true,
			get = function() return mm.db.weight_for_nonfevarite end,
			set = function(info,val) mm.db.weight_for_nonfevarite = val end,
			order = 0.3,
		},
		macro1 = {
			name = L["Macro Template"],
			desc = L["Template used to create the mm macro in the ... macro pane."],
			descStyle = "inline",
			type = "input",
			width = "full",
			multiline = 6,
			get = function() return mm.db.mm1 end,
			set = function(info,val) 
				mm.db.mm1 = val
				mm:RefreshMountList()
				mm:RefreshMacro()
			end,
			order = 0.4,
		},
	}
}

function mm:SetupOptions()
	-- Profile section
	--options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(Syllabus.db)

	-- Init the Blizzard options pannel
	_G.LibStub("AceConfig-3.0"):RegisterOptionsTable(myname, myOptionsTable)
	_G.LibStub("AceConfigDialog-3.0"):AddToBlizOptions(myname)

	-- Profile management
	local p_options = _G.LibStub("AceDBOptions-3.0"):GetOptionsTable(self.acedb)
	_G.LibStub("AceConfig-3.0"):RegisterOptionsTable(myname..'-Profile', p_options)
	_G.LibStub("AceConfigDialog-3.0"):AddToBlizOptions(myname..'-Profile', p_options.name, myname)

	-- Profile callbacks
	self.acedb.RegisterCallback(self, "OnProfileChanged", "RefreshMacro")
	self.acedb.RegisterCallback(self, "OnProfileCopied", "RefreshMacro")
	self.acedb.RegisterCallback(self, "OnProfileReset", "RefreshMacro")


	-- About section (only if someone else has included LibAboutPanel)
	if _G.LibStub:GetLibrary("LibAboutPanel", true) then
		_G.LibStub:GetLibrary("LibAboutPanel").new(myname, myname)
	end
end